==> hopach_1.14.0.zip: hopach/doc/hopach.R <==
###################################################
### chunk number 1: golub
###################################################
library(hopach)
data(golub)


###################################################
### chunk number 2: geneSelection
###################################################
vars<-apply(golub,1,var)
subset<-vars>quantile(vars,(nrow(golub)-200)/nrow(golub))
golub.subset<-golub[subset,]
dim(golub.subset)
gnames.subset<-golub.gnames[subset,]


###################################################
### chunk number 3: distance
###################################################
gene.dist<-distancematrix(golub.subset,"cosangle")
dim(gene.dist)


###################################################
### chunk number 4: hopachGene
###################################################
gene.hobj<-hopach(golub.subset,dmat=gene.dist)
gene.hobj$clust$k  
table(gene.hobj$clust$labels) 
gene.hobj$clust$sizes 


###################################################
### chunk number 5: dplot eval=FALSE
###################################################
## dplot(gene.dist,gene.hobj,ord="final",main="Golub AML/ALL Data (1999): Gene Distance Matrix",showclusters=FALSE)  


###################################################
### chunk number 6: bootstrap
###################################################
bobj<-boothopach(golub.subset,gene.hobj,B=100)


###################################################
### chunk number 7: bootplot eval=FALSE
###################################################
## bootplot(bobj,gene.hobj,ord="bootp",main="Golub AML/ALL Data (1999)",showclusters=FALSE)


###################################################
### chunk number 8: classes eval=FALSE
###################################################
## table(golub.cl)


###################################################
### chunk number 9: hopachArray
###################################################
array.hobj<-hopach(t(golub.subset),d="euclid")
array.hobj$clust$k


###################################################
### chunk number 10: output eval=FALSE
###################################################
## makeoutput(golub.subset,gene.hobj,bobj,file="Golub.out",gene.names=gnames.subset[,3])


###################################################
### chunk number 11: fuzzy eval=FALSE
###################################################
## boot2fuzzy(golub.subset,bobj,gene.hobj,array.hobj,file="GolubFuzzy",gene.names=gnames.subset[,3]) 


###################################################
### chunk number 12: hierarchical eval=FALSE
###################################################
## hopach2tree(golub.subset,file="GolubTree",hopach.genes=gene.hobj,hopach.arrays=NULL,dist.genes=gene.dist,gene.names=gnames.subset[,3])

==> hopach_2.10.0.zip: hopach/doc/hopach.R <==
###################################################
### chunk number 1: golub
###################################################
#line 69 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
library(hopach)
data(golub)


###################################################
### chunk number 2: geneSelection
###################################################
#line 76 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
vars<-apply(golub,1,var)
subset<-vars>quantile(vars,(nrow(golub)-200)/nrow(golub))
golub.subset<-golub[subset,]
dim(golub.subset)
gnames.subset<-golub.gnames[subset,]


###################################################
### chunk number 3: distance
###################################################
#line 86 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
gene.dist<-distancematrix(golub.subset,"cosangle")
dim(gene.dist)


###################################################
### chunk number 4: hopachGene
###################################################
#line 93 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
gene.hobj<-hopach(golub.subset,dmat=gene.dist)
gene.hobj$clust$k  
table(gene.hobj$clust$labels) 
gene.hobj$clust$sizes 


###################################################
### chunk number 5: dplot eval=FALSE
###################################################
## #line 102 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
## dplot(gene.dist,gene.hobj,ord="final",main="Golub AML/ALL Data (1999): Gene Distance Matrix",showclusters=FALSE)  


###################################################
### chunk number 6: bootstrap
###################################################
#line 111 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
bobj<-boothopach(golub.subset,gene.hobj,B=100)


###################################################
### chunk number 7: bootplot eval=FALSE
###################################################
## #line 117 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
## bootplot(bobj,gene.hobj,ord="bootp",main="Golub AML/ALL Data (1999)",showclusters=FALSE)


###################################################
### chunk number 8: classes eval=FALSE
###################################################
## #line 126 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
## table(golub.cl)


###################################################
### chunk number 9: hopachArray
###################################################
#line 132 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
array.hobj<-hopach(t(golub.subset),d="euclid")
array.hobj$clust$k


###################################################
### chunk number 10: output eval=FALSE
###################################################
## #line 144 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
## makeoutput(golub.subset,gene.hobj,bobj,file="Golub.out",gene.names=gnames.subset[,3])


###################################################
### chunk number 11: fuzzy eval=FALSE
###################################################
## #line 152 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
## boot2fuzzy(golub.subset,bobj,gene.hobj,array.hobj,file="GolubFuzzy",gene.names=gnames.subset[,3]) 


###################################################
### chunk number 12: hierarchical eval=FALSE
###################################################
## #line 162 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiZb79e/R.INSTALL2f8e3416/hopach/inst/doc/hopach.Rnw"
## hopach2tree(golub.subset,file="GolubTree",hopach.genes=gene.hobj,hopach.arrays=NULL,dist.genes=gene.dist,gene.names=gnames.subset[,3])
